==> jp.sourceforge.tomoyo.GUI_1.0.0.v20070618-0900.src.zip: jp.sourceforge.tomoyo.ui.editor/src/jp/sourceforge/tomoyo/ui/editor/form/profile/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2007  NTT DATA CORPORATION
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Version: 1.0.0 - 2007/06/15
 *          initial API and implementation
 *******************************************************************************/
package jp.sourceforge.tomoyo.ui.editor.form.profile;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "jp.sourceforge.tomoyo.ui.editor.form.profile.messages"; //$NON-NLS-1$
	public static String ProfileViewerLabelProvider_Customized;
	public static String ProfileViewerLabelProvider_CustomizedBackcolor;
	public static String ProfileViewerLabelProvider_CustomizedDescription;
	public static String ProfileViewerLabelProvider_CustomizedForecolor;
	public static String ProjectProfilePage_CollapseAllButtonToolTip;
	public static String ProjectProfilePage_CreateNewProfileButtonToolTip;
	public static String ProjectProfilePage_ExpandAllButtonToolTip;
	public static String ProjectProfilePage_FormTitle;
	public static String ProjectProfilePage_InputErrorDialogTitle;
	public static String ProjectProfilePage_MustBeNumberErrorMessage;
	public static String ProjectProfilePage_MustBetweenErrorMessage;
	public static String ProjectProfilePage_MustBetweenErrorMessageAnd;
	public static String ProjectProfilePage_PageDescription;
	public static String ProjectProfilePage_PageTitle;
	public static String ProjectProfilePage_ProfileTableSectionTitle;
	public static String ProjectProfilePage_ResetChangesButtonToolTip;
	public static String ProjectProfilePage_SaveChangesButtonToolTip;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> jp.sourceforge.tomoyo.GUI_1.0.1.v20070713-1200.src.zip: jp.sourceforge.tomoyo.ui.editor/src/jp/sourceforge/tomoyo/ui/editor/form/profile/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2007  NTT DATA CORPORATION
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Version: 1.0.0 - 2007/06/15
 *          initial API and implementation
 *******************************************************************************/
package jp.sourceforge.tomoyo.ui.editor.form.profile;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "jp.sourceforge.tomoyo.ui.editor.form.profile.messages"; //$NON-NLS-1$
	public static String ProfileViewerLabelProvider_Customized;
	public static String ProfileViewerLabelProvider_CustomizedBackcolor;
	public static String ProfileViewerLabelProvider_CustomizedDescription;
	public static String ProfileViewerLabelProvider_CustomizedForecolor;
	public static String ProjectProfilePage_CollapseAllButtonToolTip;
	public static String ProjectProfilePage_CreateNewProfileButtonToolTip;
	public static String ProjectProfilePage_ExpandAllButtonToolTip;
	public static String ProjectProfilePage_FormTitle;
	public static String ProjectProfilePage_InputErrorDialogTitle;
	public static String ProjectProfilePage_MustBeNumberErrorMessage;
	public static String ProjectProfilePage_MustBetweenErrorMessage;
	public static String ProjectProfilePage_MustBetweenErrorMessageAnd;
	public static String ProjectProfilePage_PageDescription;
	public static String ProjectProfilePage_PageTitle;
	public static String ProjectProfilePage_ProfileTableSectionTitle;
	public static String ProjectProfilePage_ResetChangesButtonToolTip;
	public static String ProjectProfilePage_SaveChangesButtonToolTip;
	public static String ProjectProfilePage_SaveConfirmationMessage;
	public static String ProjectProfilePage_SaveConfirmationTitle;
	public static String ProjectProfilePage_StartWizardConfirmationMessage;
	public static String ProjectProfilePage_StartWizardConfirmationTitle;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
